==> haskell-hspec-expectations-0.8.2-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-expectations
version: 0.8.2
id: hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah
key: hspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah
license: MIT
copyright: (c) 2011-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-expectations#readme
synopsis: Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>
category: Testing
author: Simon Hengel <sol@typeful.net>
exposed: True
indefinite: False
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib
hidden-modules: Test.Hspec.Expectations.Matcher
                Paths_hspec_expectations
abi: 5afe9736addd87df0f3d46c5877c97a9
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-expectations-0.8.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/hspec-expectations-0.8.2
hs-libraries: HShspec-expectations-0.8.2-IgJxviRXjDtLn1BmxNwtah
depends:
    base-4.10.1.0 call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei
    HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei=f637009e526e2490e52d1ac470f88ae2
             HUnit-1.6.0.0-AX6otQL79amDimk89yA6v4=55cadea04bfe420efb47c0d18f2d6d9c
haddock-interfaces: /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock
haddock-html: /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-expectations-0.8.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-expectations.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-expectations
version: 0.8.2
id: hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
key: hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
license: MIT
copyright: (c) 2011-2015 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
homepage: https://github.com/hspec/hspec-expectations#readme
synopsis: Catchy combinators for HUnit
description:
    Catchy combinators for HUnit: <https://github.com/hspec/hspec-expectations#readme>
category: Testing
abi: b60f2645f80233f10ada5fd31bdd8685
exposed: True
exposed-modules:
    Test.Hspec.Expectations Test.Hspec.Expectations.Contrib
hidden-modules: Test.Hspec.Expectations.Matcher
                Paths_hspec_expectations
import-dirs: /usr/lib/ghc-8.4.2/site-local/hspec-expectations-0.8.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/hspec-expectations-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/hspec-expectations-0.8.2
hs-libraries: HShspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
depends:
    base-4.11.1.0 call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=ff395d255c93ce5436421522345a92c8
             HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=321499f0791ac455defaccdaf7e9b320
haddock-interfaces: /usr/share/doc/haskell-hspec-expectations/html/hspec-expectations.haddock
haddock-html: /usr/share/doc/haskell-hspec-expectations/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
